unquad.estimation.weighted\_conformal.WeightedConformalDetector
===============================================================

.. currentmodule:: unquad.estimation.weighted_conformal

.. autoclass:: WeightedConformalDetector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~WeightedConformalDetector.__init__
      ~WeightedConformalDetector.fit
      ~WeightedConformalDetector.predict
   
   

   
   
   